# Contributors

* Damián Silvani <damian@dymaxionlabs.com>
* María Roberta Devesa <ro.devesa@dymaxionlabs.com>
* Gessica Paniagua <gessica@dymaxionlabs.com>
* Federico Bayle <federico@dymaxionlabs.com>
* Alan Toris
